module PackagecloudDebtools
  class Changes
    attr_accessor :fields, :io, :dirname, :control_file

    def initialize(io, fields)
      @fields = fields
      @io = io
      @dirname = ::File.dirname(@io.path)
      @control_file = GpgVerifier.verify_and_extract(@io)
    end

    def files
     files = @fields['files'].inject({}) do |memo, file|
        memo[file.filename] =  {  filename:   file.filename,
                                  md5sum:     file.checksum.hash,
                                  section:    file.section,
                                  priority:   file.priority,
                                  size:       file.size }
        memo
      end

     ['sha1', 'sha256'].each do |sumtype|
      files = @fields["checksums-#{sumtype}"].inject(files) do |memo, csum|
        filename = csum.filename
        memo[filename][:"#{sumtype}sum"] = csum.hash
        memo
       end
     end

     files.values
    end

    def add_to_current_section(line, section)
      section = section.downcase
      if section == "files"
        @fields[section] << File.parse(line, @dirname)
      elsif section =~ /checksums-sha[0-9]+/
        @fields[section] << Checksum.parse(line, @dirname)
      else
        @fields[section] << line.strip
      end
    end
  end
end
